==> instantsearch-android-3.0.0-sources.jar: commonMain/com/algolia/instantsearch/searchbox/SearchBoxConnector.kt <==
package com.algolia.instantsearch.searchbox

import com.algolia.instantsearch.core.connection.AbstractConnection
import com.algolia.instantsearch.core.searchbox.SearchBoxViewModel
import com.algolia.instantsearch.core.searcher.Debouncer
import com.algolia.instantsearch.core.searcher.Searcher
import com.algolia.instantsearch.core.searcher.debounceSearchInMillis
import com.algolia.instantsearch.extension.traceSearchBoxConnector

/**
 * The SearchBox is used to perform a text-based query.
 *
 * @param searcher the Searcher that handles your searches
 * @param viewModel the business logic that handles new search inputs
 * @param searchMode searchMode.AsYouType` will trigger a search on each keystroke. `SearchMode.OnSubmit` will trigger
 * a search on submitting the query
 * @param debouncer delays searcher operations by a specified time duration
 */
public data class SearchBoxConnector<R>(
    public val searcher: Searcher<R>,
    public val viewModel: SearchBoxViewModel = SearchBoxViewModel(),
    public val searchMode: SearchMode = SearchMode.AsYouType,
    public val debouncer: Debouncer = Debouncer(debounceSearchInMillis),
) : AbstractConnection() {

    private val connectionSearcher = viewModel.connectSearcher(searcher, searchMode, debouncer)

    init {
        traceSearchBoxConnector()
    }

    override fun connect() {
        super.connect()
        connectionSearcher.connect()
    }

    override fun disconnect() {
        super.disconnect()
        connectionSearcher.disconnect()
    }
}

==> instantsearch-android-3.3.3-sources.jar: commonMain/com/algolia/instantsearch/searchbox/SearchBoxConnector.kt <==
package com.algolia.instantsearch.searchbox

import com.algolia.instantsearch.core.connection.AbstractConnection
import com.algolia.instantsearch.core.searchbox.SearchBoxViewModel
import com.algolia.instantsearch.core.searcher.Debouncer
import com.algolia.instantsearch.core.searcher.Searcher
import com.algolia.instantsearch.core.searcher.debounceSearchInMillis
import com.algolia.instantsearch.extension.traceSearchBoxConnector

/**
 * The SearchBox is used to perform a text-based query.
 *
 * @param searcher the Searcher that handles your searches
 * @param viewModel the business logic that handles new search inputs
 * @param searchMode searchMode.AsYouType` will trigger a search on each keystroke. `SearchMode.OnSubmit` will trigger
 * a search on submitting the query
 * @param debouncer delays searcher operations by a specified time duration
 */
public data class SearchBoxConnector<R>(
    public val searcher: Searcher<R>,
    public val viewModel: SearchBoxViewModel = SearchBoxViewModel(),
    public val searchMode: SearchMode = SearchMode.AsYouType,
    public val debouncer: Debouncer = Debouncer(debounceSearchInMillis),
    public val searchOnQueryUpdate: Boolean = true,
) : AbstractConnection() {

    private val connectionSearcher = viewModel.connectSearcher(searcher, searchMode, debouncer, searchOnQueryUpdate)

    init {
        traceSearchBoxConnector()
    }

    override fun connect() {
        super.connect()
        connectionSearcher.connect()
    }

    override fun disconnect() {
        super.disconnect()
        connectionSearcher.disconnect()
    }
}
